# Pymatris 📂


[![Pyversions](https://img.shields.io/pypi/pyversions/pymatris.svg?style=flat-square)](https://pypi.python.org/pypi/pymatris)

Parallel file downloader for HTTP/HTTPS/FTP/SFTP protocols. 




##  How to Use
-----
```bash
pip install pymatris
```






# 


